@@ -885,18 +885,21 @@ class Confluence(AtlassianRestAPI):
 
         return (self.get(url) or {}).get('results')
 
-    def get_group_members(self, group_name='confluence-users', start=0, limit=1000):
+    def get_group_members(self, group_name='confluence-users', start=0, limit=1000, expand=None):
         """
         Get a paginated collection of users in the given group
         :param group_name
         :param start: OPTIONAL: The start point of the collection to return. Default: None (0).
         :param limit: OPTIONAL: The limit of the number of users to return, this may be restricted by
                             fixed system limits. Default: 1000
+        :param expand: OPTIONAL: A comma separated list of properties to expand on the content. status
         :return:
         """
-        url = 'rest/api/group/{group_name}/member?limit={limit}&start={start}'.format(group_name=group_name,
-                                                                                      limit=limit,
-                                                                                      start=start)
+        url = 'rest/api/group/{group_name}/member?limit={limit}&start={start}&expand={expand}'.format(
+            group_name=group_name,
+            limit=limit,
+            start=start,
+            expand=expand)
         return (self.get(url) or {}).get('results')
 
     def get_space(self, space_key, expand='description.plain,homepage'):
@@ -1332,7 +1335,7 @@ class Confluence(AtlassianRestAPI):
         output.append(page_id)
         children_pages = self.get_page_child_by_type(page_id)
         for page in children_pages:
-            child_subtree = self.get_subtree_of_content_ids(self, page.get('id'))
+            child_subtree = self.get_subtree_of_content_ids(page.get('id'))
             if child_subtree:
                 output.extend([p for p in child_subtree])
         return set(output)
